summaryrefslogtreecommitdiffstats
path: root/src/build/buildpnor/buildBpmFlashImages.pl
diff options
context:
space:
mode:
Diffstat (limited to 'src/build/buildpnor/buildBpmFlashImages.pl')
-rwxr-xr-xsrc/build/buildpnor/buildBpmFlashImages.pl4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/build/buildpnor/buildBpmFlashImages.pl b/src/build/buildpnor/buildBpmFlashImages.pl
index 5b4ecaea2..ba65dab0a 100755
--- a/src/build/buildpnor/buildBpmFlashImages.pl
+++ b/src/build/buildpnor/buildBpmFlashImages.pl
@@ -281,13 +281,13 @@ sub generateOutputNameAndVersion
# According to the spec an example filename would be of the form:
# S R C A80 6 2 IBM H 01 1 B _FULL_ FW_Rev1.03_02282019.txt
# ^ ^ ^
# 1: Number of NVDIMM interfaces (1 = 36GB, 2 = 16GB)
# _FULL_: The image contains the firmware and configuration data.
# Rev1.03: Version of this image file
my @fileNameComponents = split(/_/, $name);
# The NVDIMM interface types supported
- my %nvdimmTypes = ( 1 => "36GB",
+ my %nvdimmTypes = ( 1 => "32GB",
2 => "16GB", );
# Extract the NVDIMM Interface number from filename
OpenPOWER on IntegriCloud
@@ -281,13 +281,13 @@ sub generateOutputNameAndVersion
# S R C A80 6 2 IBM H 01 1 B _FULL_ FW_Rev1.03_02282019.txt
# ^ ^ ^
- # 1: Number of NVDIMM interfaces (1 = 36GB, 2 = 16GB)
+ # 1: Number of NVDIMM interfaces (1 = 32GB, 2 = 16GB)
# _FULL_: The image contains the firmware and configuration data.
# Rev1.03: Version of this image file